import request from "@/utils/request";
const api = "/mosty-api/mosty-gsxt";
// 群体性质新增
export const tbGsxtZdqtAdd = (data) => {
  return request({
    url: api + "/tbGsxtZdqt/save",
    method: "POST",
    data
  });
}
export const tbGsxtZdqtUpdate = (data) => {
  return request({
    url: api + "/tbGsxtZdqt/update",
    method: "POST",
    data
  });
};
// 群体查询单条
export const tbGsxtZdqtSelectVoById = (id) => {
  return request({
    url: api + "/tbGsxtZdqt/selectVoById/" + id,
    method: "GET",
  });
}


// 新增群体性质
export const tbZdqtQtxzAdd = (data) => {
  return request({
    url: api + "/tbZdqtQtxz/add",
    method: "POST",
    data
  });
}

// 批量新增群体性质
export const tbZdqtQtxzBatchAdd = (data) => {
  return request({
    url: api + "/tbZdqtQtxz/batchAdd",
    method: "POST",
    data
  });
}
// 批量删除群体性质
export const tbZdqtQtxzBatchDelete = (data) => {
  return request({
    url: api + "/tbZdqtQtxz/delete",
    method: "POST",
    data
  });
}
// 群体性质查询列表
export const tbZdqtQtxzSelectPage = (params) => {
  return request({
    url: api + "/tbZdqtQtxz/selectPage",
    method: "get",
    params
  });
}
// 群体性质更新
export const tbZdqtQtxzUpdate = (data) => {
  return request({
    url: api + "/tbZdqtQtxz/update",
    method: "POST",
    data
  });
}
// 重点群体管控信息 -（批量新增）
export const tbZdqtGkxxBatchAdd = (data) => {
  return request({
    url: api + "/tbZdqtGkxx/batchAdd",
    method: "POST",
    data
  });
}
// 重点群体管控信息 -（删除）
export const tbZdqtGkxxDelete = (data) => {
  return request({
    url: api + "/tbZdqtGkxx/delete",
    method: "POST",
    data
  });
}
// 重点群体管控信息 -（查询列表）
export const tbZdqtGkxxSelectPage = (params) => {
  return request({
    url: api + "/tbZdqtGkxx/selectPage",
    method: "get",
    params
  });
}
// 重点群体诉求-（新增）
export const tbZdqtSqAdd = (data) => {
  return request({
    url: api + "/tbZdqtSq/add",
    method: "POST",
    data
  });
}
export const tbZdqtSqBatchAdd = (data) => {
  return request({
    url: api + "/tbZdqtSq/batchAdd",
    method: "POST",
    data
  });
}




// 重点群体诉求 -（删除）
export const tbZdqtSqDelete = (data) => {
  return request({
    url: api + "/tbZdqtSq/delete",
    method: "POST",
    data
  });
}
// 重点群体诉求 -（更新）
export const tbZdqtSqUpdate = (data) => {
  return request({
    url: api + "/tbZdqtSq/update",
    method: "POST",
    data
  });
}
// 重点群体诉求 -（查询列表）
export const tbZdqtSqSelectPage = (params) => {
  return request({
    url: api + "/tbZdqtSq/selectPage",
    method: "get",
    params
  });
}
// 重点群体研判 -（新增）
export const tbZdqtYpAdd = (data) => {
  return request({
    url: api + "/tbZdqtYp/add",
    method: "POST",
    data
  });
}
// 重点群体研判 -（删除）
export const tbZdqtYpDelete = (data) => {
  return request({
    url: api + "/tbZdqtYp/delete",
    method: "POST",
    data
  });
}
// 重点群体研判 -（查询列表）
export const tbZdqtYpSelectPage = (params) => {
  return request({
    url: api + "/tbZdqtYp/selectPage",
    method: "get",
    params
  });
}
// 重点群体研判 -（更新）
export const tbZdqtYpUpdate = (data) => {
  return request({
    url: api + "/tbZdqtYp/update",
    method: "POST",
    data
  });
}
// 重点群体历史集会 -（新增）
export const tbZdqtLsjhAdd = (data) => {
  return request({
    url: api + "/tbZdqtLsjh/add",
    method: "POST",
    data
  });
}
// 重点群体历史集会 -（删除）
export const tbZdqtLsjhDelete = (data) => {
  return request({
    url: api + "/tbZdqtLsjh/delete",
    method: "POST",
    data
  });
}
// 重点群体历史集会 -（查询列表）
export const tbZdqtLsjhSelectPage = (params) => {
  return request({
    url: api + "/tbZdqtLsjh/selectPage",
    method: "get",
    params
  });
}
// 重点群体历史集会 -（更新）
export const tbZdqtLsjhUpdate = (data) => {
  return request({
    url: api + "/tbZdqtLsjh/update",
    method: "POST",
    data
  });
}
// 重点群体工作记录 -（新增）
export const tbZdqtGzjlAdd = (data) => {
  return request({
    url: api + "/tbZdqtGzjl/add",
    method: "POST",
    data
  });
}
// 重点群体工作记录 -（删除）
export const tbZdqtGzjlDelete = (data) => {
  return request({
    url: api + "/tbZdqtGzjl/delete",
    method: "POST",
    data
  });
}
// 重点群体工作记录 -（查询）
export const tbZdqtGzjlSelectPage = (params) => {
  return request({
    url: api + "/tbZdqtGzjl/selectPage",
    method: "get",
    params
  });
}
// 重点群体工作记录 -（修改）
export const tbZdqtGzjlUpdate = (data) => {
  return request({
    url: api + "/tbZdqtGzjl/update",
    method: "POST",
    data
  });
}
// 统计
// 群体人员管控级别统计（app）
export function zdryGkjbtj(params) {
  return request({
    url: api + `/tbGsxtZdqt/zdryGkjbtj`,
    method: "get",
    params
  })
}
// 群体人员业务类别统计（app）
export function zdryYwlbtj(params) {
  return request({
    url: api + `/tbGsxtZdqt/zdryYwlbtj`,
    method: "get",
    params
  })
}
// 	重点人-区域统计
export function zdryQytj(params) {
  return request({
    url: api + `/tbGsxtZdqt/zdrQytj`,
    method: "get",
    params
  })
}
// 群体人员年龄段统计（app）
export function zdryNldtj(params) {
  return request({
    url: api + `/tbGsxtZdqt/zdryNldtj`,
    method: "get",
    params
  })
}
// 群体人员职业类别统计（app）
export function zdryZclbtj(params) {
  return request({
    url: api + `/tbGsxtZdqt/zdryZylbtj`,
    method: "get",
    params
  })
}
// 群体人员文化程度统计（app）
export function zdryWhcdtj(params) {
  return request({
    url: api + `/tbGsxtZdqt/zdryWhcdtj`,
    method: "get",
    params
  })
}
